sequencetools.iterate_sequence_pairwise_cyclic
==============================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_pairwise_cyclic.iterate_sequence_pairwise_cyclic
